@@ -1,8 +1,7 @@
 package dynamodb
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -70,27 +69,23 @@ resource "aws_dax_cluster" "good_example" {
 		RequiredLabels:  []string{"aws_dax_cluster"},
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
-
 			if resourceBlock.MissingChild("server_side_encryption") {
-				res := result.New(resourceBlock).
-					WithDescription(fmt.Sprintf("DAX cluster '%s' does not have server side encryption configured. By default it is disabled.", resourceBlock.FullName()))
-				set.Add(res)
+				set.AddResult().
+					WithDescription("DAX cluster '%s' does not have server side encryption configured. By default it is disabled.", resourceBlock.FullName())
 				return
 			}
 
 			sseBlock := resourceBlock.GetBlock("server_side_encryption")
 			if sseBlock.MissingChild("enabled") {
-				res := result.New(resourceBlock).
-					WithDescription(fmt.Sprintf("DAX cluster '%s' server side encryption block is empty. By default SSE is disabled.", resourceBlock.FullName()))
-				set.Add(res)
-				return
+				set.AddResult().
+					WithDescription("DAX cluster '%s' server side encryption block is empty. By default SSE is disabled.", resourceBlock.FullName()).
+					WithBlock(sseBlock)
 			}
 
 			if sseEnabledAttr := sseBlock.GetAttribute("enabled"); sseEnabledAttr.IsFalse() {
-				res := result.New(resourceBlock).
-					WithDescription(fmt.Sprintf("DAX cluster '%s' has disabled server side encryption", resourceBlock.FullName())).
+				set.AddResult().
+					WithDescription("DAX cluster '%s' has disabled server side encryption", resourceBlock.FullName()).
 					WithAttribute(sseEnabledAttr)
-				set.Add(res)
 			}
 
 		},
