@@ -1,8 +1,7 @@
 package ecr
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -14,8 +13,6 @@ import (
 
 	"github.com/aquasecurity/tfsec/pkg/rule"
 
-	"github.com/zclconf/go-cty/cty"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
 )
 
@@ -63,27 +60,20 @@ resource "aws_ecr_repository" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, context *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("image_scanning_configuration") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines a disabled ECR image scan.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' defines a disabled ECR image scan.", resourceBlock.FullName())
 				return
 			}
 
-			ecrScanStatusBlock := resourceBlock.GetBlock("image_scanning_configuration")
-			ecrScanStatusAttr := ecrScanStatusBlock.GetAttribute("scan_on_push")
+			ecrScanStatusAttr := resourceBlock.GetNestedAttribute("image_scanning_configuration.scan_on_push")
 
-			if ecrScanStatusAttr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines a disabled ECR image scan.", resourceBlock.FullName())),
-				)
-			} else if ecrScanStatusAttr.Type() == cty.Bool && ecrScanStatusAttr.Value().False() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines a disabled ECR image scan.", resourceBlock.FullName())).
-						WithAttribute(ecrScanStatusAttr),
-				)
+			if ecrScanStatusAttr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines a disabled ECR image scan.", resourceBlock.FullName())
+			} else if ecrScanStatusAttr.IsFalse() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines a disabled ECR image scan.", resourceBlock.FullName()).
+					WithAttribute(ecrScanStatusAttr)
 			}
 		},
 	})
