@@ -1,8 +1,7 @@
 package elbv2
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -59,14 +58,14 @@ resource "aws_alb_listener" "good_example" {
 
 			protocolAttr := resourceBlock.GetAttribute("protocol")
 
-			if protocolAttr != nil {
+			if protocolAttr.IsNotNil() {
 				if protocolAttr.IsResolvable() && (protocolAttr.Equals("HTTPS", block.IgnoreCase) ||
 					protocolAttr.Equals("TLS", block.IgnoreCase)) {
 					return
 				}
 				if protocolAttr.IsResolvable() && protocolAttr.Equals("HTTP") {
 					// check if this is a redirect to HTTPS - if it is, then no problem
-					if redirectProtocolAttr := resourceBlock.GetNestedAttribute("default_action/redirect/protocol"); redirectProtocolAttr != nil {
+					if redirectProtocolAttr := resourceBlock.GetNestedAttribute("default_action.redirect.protocol"); redirectProtocolAttr.IsNotNil() {
 						if redirectProtocolAttr.IsResolvable() && redirectProtocolAttr.Equals("HTTPS") {
 							return
 						}
@@ -74,14 +73,9 @@ resource "aws_alb_listener" "good_example" {
 				}
 			}
 
-			res := result.New(resourceBlock).
-				WithDescription(fmt.Sprintf("Resource '%s' uses plain HTTP instead of HTTPS.", resourceBlock.FullName()))
-
-			if protocolAttr != nil {
-				res.WithAttribute(protocolAttr)
-			}
-
-			set.Add(res)
+			set.AddResult().
+				WithDescription("Resource '%s' uses plain HTTP instead of HTTPS.", resourceBlock.FullName()).
+				WithAttribute(protocolAttr)
 
 		},
 	})
