@@ -1,8 +1,7 @@
 package database
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -57,20 +56,16 @@ resource "azurerm_postgresql_server" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("public_network_access_enabled") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has default public network access of enabled", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has default public network access of enabled", resourceBlock.FullName())
 				return
 			}
 
 			publicAccessAttr := resourceBlock.GetAttribute("public_network_access_enabled")
 			if publicAccessAttr.IsTrue() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has public access explicitly enabled", resourceBlock.FullName())).
-						WithAttribute(publicAccessAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has public access explicitly enabled", resourceBlock.FullName()).
+					WithAttribute(publicAccessAttr)
 			}
 		},
 	})
