@@ -1,8 +1,7 @@
 package network
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -107,11 +106,10 @@ resource "azurerm_network_security_group" "example" {
 				}
 				if securityRule.HasChild("destination_port_range") && securityRule.GetAttribute("destination_port_range").Contains("3389") {
 					if securityRule.HasChild("source_address_prefix") {
-						if securityRule.GetAttribute("source_address_prefix").IsAny("*", "0.0.0.0", "/0", "internet", "any") {
-							set.Add(
-								result.New(resourceBlock).
-									WithDescription(fmt.Sprintf("Resource '%s' has a source address prefix of *, 0.0.0.0, /0, internet or an any. Consider using the Azure Bastion Service.", resourceBlock.FullName())),
-							)
+						sourceAddrAttr := securityRule.GetAttribute("source_address_prefix")
+						if sourceAddrAttr.IsAny("*", "0.0.0.0", "/0", "internet", "any") {
+							set.AddResult().
+								WithDescription("Resource '%s' has a source address prefix of *, 0.0.0.0, /0, internet or an any. Consider using the Azure Bastion Service.", resourceBlock.FullName()).WithAttribute(sourceAddrAttr)
 						}
 					}
 				}
